"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultOptions = void 0;
const clipboardy_1 = __importDefault(require("clipboardy"));
const consola_1 = __importDefault(require("consola"));
const moren_1 = __importDefault(require("moren"));
const open_1 = __importDefault(require("open"));
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const createWebpackConfig_1 = __importDefault(require("./lib/createWebpackConfig"));
exports.DefaultOptions = {
    define: {
        'process.env.NODE_ENV': 'development'
    },
    port: 8080,
    open: true,
    clipboard: false,
    htmlTitle: 'Vue Dev Server',
    webpackBarName: 'Vue Dev Server'
};
function serve(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const finalOptions = moren_1.default(options, exports.DefaultOptions);
        const { entry, port, open, clipboard } = finalOptions;
        if (!entry) {
            consola_1.default.error('Missing "entry".');
            return;
        }
        const serverUrl = `http://localhost:${port}`;
        const webpackConfig = createWebpackConfig_1.default(finalOptions);
        const devConfig = webpackConfig.devServer;
        webpack_dev_server_1.default.addDevServerEntrypoints(webpackConfig, devConfig);
        const compiler = webpack_1.default(webpackConfig);
        const server = new webpack_dev_server_1.default(compiler, devConfig);
        yield new Promise((resolve, reject) => {
            server.listen(port, '0.0.0.0', err => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
        yield Promise.all([
            clipboard ? clipboardy_1.default.write(serverUrl) : Promise.resolve(),
            open ? open_1.default(serverUrl) : Promise.resolve()
        ]);
    });
}
exports.default = serve;
module.exports = serve;
//# sourceMappingURL=index.js.map