"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const friendly_errors_webpack_plugin_1 = __importDefault(require("friendly-errors-webpack-plugin"));
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const path_1 = require("path");
const terminal_link_1 = __importDefault(require("terminal-link"));
const plugin_1 = __importDefault(require("vue-loader/lib/plugin"));
const webpack_1 = require("webpack");
const webpackbar_1 = __importDefault(require("webpackbar"));
const stringifyDefine_1 = __importDefault(require("./stringifyDefine"));
const getCSSUses_1 = __importDefault(require("./getCSSUses"));
function createWebpackConfig(options) {
    const { entry, alias, define, port, htmlTitle, webpackBarName } = options;
    const vuePath = path_1.dirname(require.resolve('vue'));
    const builtInAlias = {
        '@': path_1.resolve(process.cwd(), './src')
    };
    const finalAlias = Object.assign(Object.assign({}, builtInAlias), alias);
    const stringifiedDefine = stringifyDefine_1.default(define);
    const serverUrl = `http://localhost:${port}`;
    const serverLink = terminal_link_1.default(serverUrl, serverUrl, {
        fallback: () => serverUrl
    });
    const config = {
        mode: 'development',
        entry,
        module: {
            rules: [
                {
                    test: /\.vue$/,
                    loader: 'vue-loader',
                    options: {
                        hotReload: true,
                        productionMode: false
                    }
                },
                {
                    test: /\.ts$/,
                    loader: 'ts-loader',
                    options: {
                        compilerOptions: {
                            sourceMap: true
                        },
                        appendTsSuffixTo: [/\.vue$/]
                    }
                },
                {
                    test: /\.css$/,
                    use: getCSSUses_1.default()
                },
                {
                    test: /\.scss$/,
                    use: [
                        ...getCSSUses_1.default(2),
                        {
                            loader: 'sass-loader',
                            options: {
                                sourceMap: true
                            }
                        }
                    ]
                },
                {
                    test: /\.pug$/,
                    oneOf: [
                        {
                            resourceQuery: /^\?vue/,
                            loader: 'pug-plain-loader'
                        },
                        {
                            loader: 'pug-loader'
                        }
                    ]
                }
            ]
        },
        resolve: {
            alias: Object.assign({ vue$: path_1.join(vuePath, 'vue.esm.js') }, finalAlias),
            extensions: ['.wasm', '.mjs', '.vue', '.ts', '.js', '.json']
        },
        plugins: [
            ...(stringifiedDefine ? [new webpack_1.DefinePlugin(stringifiedDefine)] : []),
            new webpack_1.HotModuleReplacementPlugin(),
            new webpackbar_1.default({
                name: webpackBarName
            }),
            new friendly_errors_webpack_plugin_1.default({
                compilationSuccessInfo: {
                    messages: [
                        `You development server is running on ${serverLink}`
                    ],
                    notes: []
                }
            }),
            new plugin_1.default(),
            new html_webpack_plugin_1.default({
                title: htmlTitle,
                template: path_1.resolve(__dirname, '../../index.pug')
            })
        ],
        devtool: 'eval-source-map',
        stats: false,
        devServer: {
            host: '0.0.0.0',
            port,
            hot: true,
            inline: true,
            open: false,
            noInfo: true
        }
    };
    return config;
}
exports.default = createWebpackConfig;
//# sourceMappingURL=createWebpackConfig.js.map