"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const autoprefixer_1 = __importDefault(require("autoprefixer"));
/**
 * Get webpack rules' CSS `use`.
 *
 * @param {number} [importLoaders=1] `css-loader`'s `importLoaders`
 */
function getCSSUses(importLoaders = 1) {
    /*
     * To make `vue-style-loader` works with `css-loader` v4,
     * we need to disable `esModule`.
     *
     * See https://github.com/vuejs/vue-style-loader/issues/46
     */
    const cssUses = [
        'vue-style-loader',
        {
            loader: 'css-loader',
            options: {
                importLoaders,
                esModule: false,
                sourceMap: true
            }
        },
        {
            loader: 'postcss-loader',
            options: {
                postcssOptions: {
                    plugins: [
                        autoprefixer_1.default({
                            overrideBrowserslist: [
                                'extends browserslist-config-vue'
                            ]
                        })
                    ]
                },
                sourceMap: true
            }
        }
    ];
    return cssUses;
}
exports.default = getCSSUses;
//# sourceMappingURL=getCSSUses.js.map